@@ -1,6 +1,9 @@
-// html2hdml
-// Coprygight (C) 2000-2003 Dino Co.,Ltd.
-// http://www.dino.co.jp/
+/*
+ * html2hdml
+ *
+ * Coprygight (C) 2000-2003 Dino Co.,Ltd.
+ * http://www.dino.co.jp/
+ */
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -300,7 +303,7 @@ int alignment(void)
 int convert_text(char *text)
 {
     char *p = NULL, *enc_p = NULL;
-//    p = replace_docomochar(text);
+    /* p = replace_docomochar(text); */
     p = text;
 
     alignment();
@@ -381,7 +384,7 @@ int convert_comment(char *text)
 int convert_BR(char *stago, char *elemname, char **attr, char *tagc)
 {
   if (gl_align) {
-    // center or right
+    /* center or right */
     add_piece(enum_body, "<br>\n");
   } else {
     add_piece(enum_body, "<br>");
@@ -415,14 +418,13 @@ int convert_P(char *stago, char *elemname, char **attr, char *tagc)
       gl_last_align = gl_align;
       gl_align = ALIGN_RIGHT;
     } else {
-      // illegal :>
+      /* illegal :> */
       gl_last_align = gl_align;
       gl_align = ALIGN_LEFT;
     }
     my_free(align);
   } else {
-    // no attribute "align"
-    // keep state
+    /* no attribute "align" : keep current state */
     gl_last_align = gl_align;
   }
 
@@ -443,7 +445,7 @@ int convert_A(char *stago, char *elemname, char **attr, char *tagc)
 {
     char *href = NULL, *enc_href = NULL, *akey = NULL, *base = NULL;
     char *p;
-//    char qc; /* quoting character: [\0\'\"] */
+    /* char qc; */ /* quoting character: [\0\'\"] */
     char print_buf[BUFFER_SIZE];
 
     alignment();
@@ -685,7 +687,7 @@ int convert_FORM(char *stago, char *elemname, char **attr, char *tagc)
     /* must refine... */
     p1 = remove_quote(attr[(int)enum_ACTION]);
     if (p1 == NULL) {
-	//gl_form_dest = NULL;      
+      /* gl_form_dest = NULL; */
     } else {
 	p2 = base_url(p1);
 	if (p2) {
@@ -818,11 +820,11 @@ int convert_INPUT(char *stago, char *elemname, char **attr, char *tagc)
     char *p;
     char *name, *value, *enc_value = NULL;
     char *checked;
-//    char qc; /* quoting character: [\0\'\"] */
+    /* char qc; */ /* quoting character: [\0\'\"] */
 /*    int len = 0;*/
     char print_str[BUFFER_SIZE];
     enum inputtype type;
-    int radio_cardnum;
+    int radio_cardnum = -1; /* -1: error state */
 
     alignment();
 
@@ -1136,11 +1138,11 @@ int convert_SELECT_(char *stago, char *elemname, char **attr, char *tagc)
 
 int convert_SELECT(char *stago, char *elemname, char **attr, char *tagc)
 {
-/*    char *str;*/
-//    char *p;
+    /* char *str; */
+    /* char *p; */
     char *name = NULL;
-//    char qc; /* quoting character: [\0\'\"] */
-/*    int len = 0;*/
+    /* char qc; */ /* quoting character: [\0\'\"] */
+    /* int len = 0; */
     char print_str[BUFFER_SIZE];
 
     alignment();
@@ -1250,7 +1252,7 @@ int convert_OPTION(char *stago, char *elemname, char **attr, char *tagc)
     strcpy(print_str, "");
     if (!selected) {
 	/* t1= */
-//	sprintf(print_str, "t%d=&", gl_cardnum);
+	/* sprintf(print_str, "t%d=&", gl_cardnum); */
 	
 	/* e0= & x0= */
 	
