@@ -28,8 +28,6 @@ extern struct clientinfo gl_clientinfo;
 extern struct convertopt gl_convertopt;
 
 extern int set_inputstr(const char *input, int inputlen);
-//extern int is_permitted_execution(int a, int b);
-extern int set_vars_for_debug(int a, int b);
 
 extern int func(const char *buffer, int buf_len,
 		struct clientinfo *clientinfo,
